@@ -34,8 +34,8 @@
 #else
 	#define BOOST_AUTO_TEST_MAIN
 	#define BOOST_TEST_DYN_LINK
-	#include <boost/test/auto_unit_test.hpp>
-	#include <boost/test/floating_point_comparison.hpp>
+	#include <boost/test/unit_test.hpp>
+	#include <boost/test/tools/floating_point_comparison.hpp>
 #endif
 
 namespace UI {
